@@ -426,6 +426,8 @@ void MainWindow::setupActions()
     mShowHideAction = new QAction(QIcon::fromTheme(QStringLiteral("zoom-fit-width")),
                                   i18nc("@action:inmenu", "Hide/Show the component sidebar"), this);
     setHelpText(mShowHideAction, i18nc("@info:status", "Hide/Show the component sidebar"));
+    mShowHideAction->setCheckable(true);
+    mShowHideAction->setChecked(Prefs::self()->sideBarOpen());
     mShowHideAction->setWhatsThis(
         i18nc("@info:whatsthis",
               "Allows you to show or hide the component sidebar as desired."));
@@ -784,8 +786,13 @@ void MainWindow::selectPlugin(KontactInterface::Plugin *plugin)
         createGUI(plugin->part());
         plugin->shortcutChanged();
 
-        setCaption(i18nc("@title:window Plugin dependent window title",
-                         "%1 - Kontact", plugin->title()));
+        // KParts's guiActivateEvent emptied the caption when leaving the old part,
+        // and only some parts (like kmail) set it in guiActivateEvent when being activated.
+        // For others, this is the default caption:
+        if (windowTitle().isEmpty()) {
+            setCaption(i18nc("@title:window Plugin dependent window title",
+                        "%1 - Kontact", plugin->title()));
+        }
 
         if (newAction) {
             mNewActions->setIcon(newAction->icon());
